<?php

namespace Opencart\System\Library\Extension\Chatbro\Chatbroapp\Common;

use Opencart\System\Library\Extension\Chatbro\Chatbroapp\Core\CbroBackendable;
use Opencart\System\Library\Extension\Chatbro\Chatbroapp\Utils\CbroUtils;
use Opencart\System\Library\Extension\Chatbro\Chatbroapp\Exceptions\CBroSettingNotFound;
use Opencart\System\Library\Extension\Chatbro\Chatbroapp\Exceptions\CBroStoreNotFound;

class CbroCommon extends CbroBackendable
{

  protected function __construct($backend)
  {
    parent::__construct($backend);
  }

  public static function get_store_id()
  {
    $store_id = self::get_backend()->store_id;

    if ($store_id === null || $store_id === '') {
      throw new CBroStoreNotFound('Undefined');
    }

    return (int) self::get_backend()->db->escape($store_id);
  }

  public static function remote_post($uri, $args)
  {

    $curl_options = array();

    if (isset($args['headers'])) {

      $newHeaders = array_map(function ($key, $value) {
        return $key . ': ' . $value;
      }, array_keys($args['headers']), $args['headers']);

      // Обновление исходного массива
      $args['headers'] = $newHeaders;

      $curl_options[CURLOPT_HTTPHEADER] = $args['headers'];
    }

    if (isset($args['body'])) {
      $curl_options[CURLOPT_POST] = true;
      $curl_options[CURLOPT_POSTFIELDS] = $args['body'];
    }

    $curl_options[CURLOPT_URL] = $uri;
    $curl_options[CURLOPT_RETURNTRANSFER] = true;
    $curl_options[CURLOPT_SSL_VERIFYHOST] = false;
    $curl_options[CURLOPT_SSL_VERIFYPEER] = false;



    $ch = curl_init();
    curl_setopt_array($ch, $curl_options);
    $result = curl_exec($ch);
    $info = curl_getinfo($ch);
    curl_close($ch);

    return array(
      'result' => $result,
      'info' => $info
    );
  }

  public static function remote_retrieve_response_code($response)
  {
    return isset($response['info']['http_code']) ? (int) $response['info']['http_code'] : 500;
  }

  public static function remote_retrieve_body($response)
  {
    return isset($response['result']) ? $response['result'] : null;
  }

  public static function is_error($response)
  {
    return (int) $response['info']['http_code'] >= 404;
  }

  public static function delete_access_token()
  {
    self::delete_option('chatbro_access_token');
  }

  public static function delete_refresh_token()
  {
    self::delete_option('chatbro_refresh_token');
  }

  public static function set_access_token($access_token)
  {
    return self::update_option('chatbro_access_token', $access_token);
  }

  public static function set_refresh_token($refresh_token)
  {
    return self::update_option('chatbro_refresh_token', $refresh_token);
  }

  public static function get_access_token()
  {
    return self::get_option('chatbro_access_token');
  }

  public static function get_refresh_token()
  {
    return self::get_option('chatbro_refresh_token');
  }

  public static function get_store($store_id)
  {
    $sql = "SELECT * FROM `" . DB_PREFIX . "chatbro` WHERE store_id=" . $store_id;
    return self::get_backend()->db->query($sql)->row;
  }

  public static function reg_store()
  {
    $store_id = self::get_store_id();

    $sql = "SELECT * FROM `" . DB_PREFIX . "chatbro` WHERE store_id=" . $store_id;
    $query = self::get_backend()->db->query($sql);

    if (empty($query->rows)) {
      $guid = CbroUtils::gen_guid();
      $secret = CbroUtils::gen_secret();

      $sql = "INSERT INTO `" . DB_PREFIX . "chatbro` SET `chatbro_chat_guid`='" . $guid . "', `store_id`=" . $store_id . ", `chatbro_chat_secret`='" . $secret . "'";
      self::get_backend()->db->query($sql);
    }
  }

  public static function add_option($name, $value)
  {
    return self::update_option($name, $value);
  }

  public static function update_option($name, $value)
  {
    $store_id = self::get_store_id();
    return self::get_backend()->db->query("UPDATE " . DB_PREFIX . "chatbro SET updated_at = NOW(), `" . self::get_backend()->db->escape($name) . "`='" . self::get_backend()->db->escape($value) . "' WHERE `store_id`=" . $store_id);
  }

  public static function get_option($name, $defaultValue = null)
  {
    $store_id = self::get_store_id();
    $store = self::get_store($store_id);

    if (empty($store)) {
      throw new CBroStoreNotFound(self::get_store_id());
    }

    if (!isset($store[$name]) || is_null($store[$name])) {
      return $defaultValue;
    }

    return $store[$name];
  }

  public static function delete_option($name)
  {
    $store_id = self::get_store_id();
    $store = self::get_store($store_id);


    if (empty($store)) {
      throw new CBroStoreNotFound(self::get_store_id());
    }

    if (isset($store[$name])) {
      return self::get_backend()->db->query("UPDATE " . DB_PREFIX . "chatbro SET updated_at = NOW(), `" . self::get_backend()->db->escape($name) . "`='NULL' WHERE `store_id`=" . $store_id);
    }

    return false;
  }

  public static function delete_store()
  {
  }

  public static function generated_scripts() {
    
  }

  public static function is_logged_in()
  {
    return self::get_backend()->customer->isLogged();
  }
}