<?php

namespace Opencart\System\Library\Extension\Chatbro\Chatbroapp\Shortcodes;

use Opencart\System\Library\Extension\Chatbro\Chatbroapp\Utils\CbroUtils;
use Opencart\System\Library\Extension\Chatbro\Chatbroapp\Settings\CbroSettings;
use Opencart\System\Library\Extension\Chatbro\Chatbroapp\Chats\CbroChats;
use Opencart\System\Library\Extension\Chatbro\Chatbroapp\Chats\CbroDisplayChat;
use Opencart\System\Library\Extension\Chatbro\Chatbroapp\Users\CbroUser;
use Opencart\System\Library\Extension\Chatbro\Chatbroapp\Exceptions\CbroChatNotFound;

class CbroShortCode
{
    private static $instance = null;

    private function __construct()
    {
    }

    public static function get_instance()
    {
        if (!self::$instance) {
            self::$instance = new CBroShortCode();
        }
        return self::$instance;
    }

    public static function render($atts, $content = null)
    {
        $a = CbroUtils::merge_attributes($atts, array(
            'static' => true,
            'registered_only' => false,
            'title' => null,
            'child' => false,
            'ext_id' => null,
            'id' => null
        ));

        if (!CbroSettings::get(CbroSettings::enabled)) {
            return "";
        }

        if (!CBroSettings::get(CBroSettings::enable_shortcodes)) {
            return "";
        }

        $chat_id = $a['id'];
        $chat = null;

        if ($chat_id) {
            try {
                $chat = CBroChats::get($chat_id);
            } catch (CBroChatNotFound $ex) {
                return;
            }
        } else {
            $chat = CBroChats::get_default_chat();
        }

        if (!isset($chat)) {
            return;
        }

        $registered_only = $atts && array_key_exists('registered_only', $atts)
            ? (strtolower($a['registered_only']) == 'true' || $a['registered_only'] == '1')
            : !$chat->get_display_to_guests();


        if (!CbroUser::can_view($chat->get_display_to_guests()) || ($registered_only && !CBroUser::is_logged_in())) {
            return "";
        }

        $static = strtolower($a['static']) == 'true' || $a['static'] == '1';
        $child = strtolower($a['child']) == 'true' || $a['child'] == '1';

        if ($child && $a['title']) {
            $code = (new CbroDisplayChat($chat))->get_child_chat_code($static, $a['title'], $a['ext_id']);
        } else {
            $code = $static
                ? (new CbroDisplayChat($chat))->get_static_chat_code()
                : (new CbroDisplayChat($chat))->get_chat_code();
        }

        return $code;
    }
}
